@@ -955,8 +955,12 @@ def voigt_eq(n, k, freq, Z, sig):
     
     f_max = int(np.argwhere(convolution==convolution.max()))
     conv_sx, conv_dx = convolution[0:f_max], convolution[f_max::]
-    sx, dx = np.argwhere(conv_sx < convolution.max()/2)[-1], np.argwhere(conv_dx < convolution.max()/2)[0] + f_max
-    fv = (freq[dx] - freq[sx])[0]
+    if(len(np.argwhere(conv_sx < convolution.max()/2)) > 0):
+        sx, dx = np.argwhere(conv_sx < convolution.max()/2)[-1], np.argwhere(conv_dx < convolution.max()/2)[0] + f_max
+        fv = (freq[dx] - freq[sx])[0]
+    else:
+        dx = np.argwhere(conv_dx < convolution.max()/2)[0] + f_max
+        fv = freq[dx][0]*2
     fg = 2*sig*np.sqrt(2*np.log(2))
     a, b, c = 0.0692, -1.0692*fv, -fg**2+fv**2
     fl = (-b/2-np.sqrt((b/2)**2-a*c))/a 
